==> nautilus-cd-burner-0.1.tar.bz2: nautilus-cd-burner-0.1/nautilus-cd-burner.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-

   nautilus-cd-burner.c: easy to use cd burner software
 
   Copyright (C) 2002 Red Hat, Inc.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
  
   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
  
   Authors: Alexander Larsson <alexl@redhat.com>
*/
#include "config.h"
#include <libgnome/gnome-i18n.h>
#include <glib/glist.h>
#include <gtk/gtkwindow.h>

typedef enum {
	RECORDER_TYPE_FILE,
	RECORDER_TYPE_CD,
	RECORDER_TYPE_DVD
} CDRecorderType;

typedef struct {
	CDRecorderType type;
	char *name;
	int max_speed;
	char *id;
} CDRecorder;

typedef void (*CancelFunc) (gpointer       data);

enum {
	RESULT_ERROR,
	RESULT_CANCEL,
	RESULT_FINISHED,
	RESULT_RETRY
};

extern GList *recorders;

extern void scan_for_recorders (gboolean add_image);

extern CDRecorder *get_recorder (int nr);

extern int write_iso (CDRecorder *recorder,
		      const char *filename,
		      int speed,
		      gboolean eject,
		      gboolean dummy_write);

extern int make_iso (const char *filename,
		     const char *label);

/* UI callbacks: */
extern void cd_progress_set_text        (const char *text);
extern void cd_progress_set_fraction    (double      fraction);
extern void cd_progress_set_cancel_func (CancelFunc  cancel_func,
					 gboolean    cancel_dangerous,
					 gpointer    user_data);
GtkWindow * cd_progress_get_window      (void);

==> nautilus-cd-burner-0.2.tar.bz2: nautilus-cd-burner-0.2/nautilus-cd-burner.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-

   nautilus-cd-burner.c: easy to use cd burner software
 
   Copyright (C) 2002 Red Hat, Inc.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
  
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
  
   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
  
   Authors: Alexander Larsson <alexl@redhat.com>
*/
#include "config.h"
#include <libgnome/gnome-i18n.h>
#include <glib/glist.h>
#include <gtk/gtkwindow.h>

#include "cd-drive.h"

typedef void (*CancelFunc) (gpointer       data);

enum {
	RESULT_ERROR,
	RESULT_CANCEL,
	RESULT_FINISHED,
	RESULT_RETRY
};

extern int write_iso (CDDrive *recorder,
		      const char *filename,
		      int speed,
		      gboolean eject,
		      gboolean dummy_write);

extern int make_iso (const char *filename,
		     const char *label);

/* UI callbacks: */
extern void cd_progress_set_text        (const char *text);
extern void cd_progress_set_fraction    (double      fraction);
extern void cd_progress_set_image_spinning (gboolean spinning);
extern void cd_progress_set_cancel_func (CancelFunc  cancel_func,
					 gboolean    cancel_dangerous,
					 gpointer    user_data);
GtkWindow * cd_progress_get_window      (void);
